@@ -1,4 +1,6 @@
 __author__ = "Aaron Levi Can (aaronlyy)"
-__version__ = "0.1.5"
+__version__ = "0.1.7.1"
+
+from .shell import Shell
+from .commands import clear
 
-from .shell import Shell
\ No newline at end of file
